Thermodynamic data
==================

This folder contains thermodynamic data for TFA. The data is arranged as a 
.thermodb file, whose format and usage are specified in 
`the documentation <http://pytfa.readthedocs.io/en/latest/thermoDB.html>`_

Origin of the data
------------------
The data has been obtained from the following sources:

Jankowski, M. D., Henry, C. S., Broadbelt, L. J., & Hatzimanikatis, V. (2008). Group contribution method for thermodynamic analysis of complex metabolic networks. Biophysical journal, 95(3), 1487-1499.

Alberty, R. A. (2005). Thermodynamics of biochemical reactions. John Wiley & Sons.

